@@ -1,16 +1,20 @@
 from BeautifulSoup import BeautifulSoup, Comment
 from util import force_decode
 
-SCRIPT_PATTERN = '############ script %d ############'
+EXCLUDE_TAGS = ('script','pre',)
+
+TAGS_PATTERN = '############ %s %d ############'
 
 def html_minify(html_code, ignore_comments=True):
     html_code = force_decode(html_code)
     soup = BeautifulSoup(html_code)
-
-    scripts = [ str(script) for script in soup.findAll(name='script') if len(script.text) > 0 ]
-
-    for index, script in enumerate(scripts):
-        html_code = html_code.replace(script, SCRIPT_PATTERN % index)
+    exclude_tags = {}
+    
+    for tag in EXCLUDE_TAGS:
+        exclude_tags[tag] = [ str(script) for script in soup.findAll(name=tag) if len(script.text) > 0 ]
+        
+        for index, script in enumerate(exclude_tags[tag]):
+            html_code = html_code.replace(script, TAGS_PATTERN % (tag, index))
 
     soup = BeautifulSoup(html_code)
 
@@ -27,9 +31,10 @@ def html_minify(html_code, ignore_comments=True):
         minified_lines.append(str(minified_line))
 
     content = "".join(minified_lines)
-
-    for index, script in enumerate(scripts):
-        content = content.replace(SCRIPT_PATTERN % index, script)
+    
+    for tag in EXCLUDE_TAGS:
+        for index, script in enumerate(exclude_tags[tag]):
+            content = content.replace(TAGS_PATTERN % (tag,index), script)
 
     if "DOCTYPE" not in content:
         content = "<!DOCTYPE html>%s" % content
